@@ -1,5 +1,5 @@
 package WebAPI::DBIC::Resource::GenericItem;
-$WebAPI::DBIC::Resource::GenericItem::VERSION = '0.001008'; # TRIAL
+$WebAPI::DBIC::Resource::GenericItem::VERSION = '0.001010'; # TRIAL
 
 use Moo;
 use namespace::clean;
@@ -7,6 +7,10 @@ use namespace::clean;
 extends 'WebAPI::DBIC::Resource::GenericCore';
 with    'WebAPI::DBIC::Resource::Role::Item',
         'WebAPI::DBIC::Resource::Role::ItemWritable',
+        # Enable HAL support:
+        'WebAPI::DBIC::Resource::Role::DBIC_HAL',
+        'WebAPI::DBIC::Resource::Role::ItemHAL',
+        'WebAPI::DBIC::Resource::Role::ItemWritableHAL',
         ;
 
 1;
@@ -23,7 +27,7 @@ WebAPI::DBIC::Resource::GenericItem
 
 =head1 VERSION
 
-version 0.001008
+version 0.001010
 
 =head1 NAME
 
